pub struct Scope {
pub depth: u8,
pub operations: Vec<Operation>,
pub layout_ref: Option<Variable>,
/* private fields */
}Expand description
The scope is the main operation and variable container that simplify the process of reading inputs, creating local variables and adding new operations.
Notes:
This type isn’t responsible for creating shader bindings and figuring out which variable can be written to.
Fields
depth: u8operations: Vec<Operation>layout_ref: Option<Variable>Implementations