Module burn_jit::kernel

source ·
Kernel module

Modules

Macros

  • Creates a binary kernel.
  • Creates a unary kernel.

Enums

Traits

Functions

  • Launch an binary operation.
  • Cast a bool tensor to the given element type.
  • Cast a tensor to the given element type.
  • Make a jit tensor contiguous.
  • Execute the mask fill kernel with the given strategy.
  • Execute the mask where kernel with the given strategy.
  • Launch an unary operation.