Kernel module
Modules
- Convolution kernels
- Interpolation kernels
- Matmul kernels
- Pooling kernels
- Pseudo-random number generator kernels
- Reduction algorithms
Macros
- Creates a binary kernel.
- Creates a unary kernel.
Enums
- Define how to run the mask fill kernel.
- Define how to run the mask where kernel.
Traits
- Dynamic jit kernel to create a compute shader.
Functions
- Launch an binary operation.
- Cast a bool tensor to the given element type.
- Cast a tensor to the given element type.
- Make a jit tensor contiguous.
- Execute the mask fill kernel with the given strategy.
- Execute the mask where kernel with the given strategy.
- Launch an unary operation.